@@ -10,7 +10,7 @@ use Text::Shirasu::Node;
 use Lingua::JA::NormalizeText;
 use Encode qw/encode_utf8 decode_utf8/;
 
-our $VERSION   = "0.0.2";
+our $VERSION   = "0.0.3";
 our @EXPORT_OK = (@Lingua::JA::NormalizeText::EXPORT_OK, qw/normalize_hyphen normalize_symbols/);
 
 *nfkc                 = \&Lingua::JA::NormalizeText::nfkc;
@@ -215,13 +215,12 @@ sub filter {
         or croak 'Query has not been inputted: "type"';
 
     # create parameter as /名詞|動詞/ or /名詞/
-    my $query = join '|', @type;
-    $query = encode_utf8($query) if utf8::is_utf8 $query;
+    my $query = encode_utf8 join '|', map { $_ } @type;
 
     $self->{nodes} = [
         grep {
             $_->{feature}->[0] =~ /($query)/
-                and _sub_query( $_->{feature}->[1], $params{$1} )
+                and _sub_query( $_->{feature}->[1],  $params{decode_utf8($1)} )
         } @{ $self->{nodes} }
     ];
 
